@@ -181,15 +181,20 @@ extern "C" {
 #if __WINDOWS__
 #define FS "\\"
 #define R_SYS_DIR "\\"
+#define R_SYS_ENVSEP ";"
 #define R_SYS_HOME "USERPROFILE"
-#define R2_HOMEDIR ".config\\radare2"
 #else
 #define FS "/"
 #define R_SYS_DIR "/"
+#define R_SYS_ENVSEP ":"
 #define R_SYS_HOME "HOME"
-#define R2_HOMEDIR ".config/radare2"
 #endif
 
+#define R_JOIN_2_PATHS(p1, p2) p1 R_SYS_DIR p2
+#define R_JOIN_3_PATHS(p1, p2, p3) p1 R_SYS_DIR p2 R_SYS_DIR p3
+#define R_JOIN_4_PATHS(p1, p2, p3, p4) p1 R_SYS_DIR p2 R_SYS_DIR p3 R_SYS_DIR p4
+#define R_JOIN_5_PATHS(p1, p2, p3, p4, p5) p1 R_SYS_DIR p2 R_SYS_DIR p3 R_SYS_DIR p4 R_SYS_DIR p5
+
 #ifndef __packed
 #define __packed __attribute__((__packed__))
 #endif
@@ -341,7 +346,7 @@ static inline void *r_new_copy(int size, void *data) {
 #define R_ABS(x) (((x)<0)?-(x):(x))
 #define R_BTW(x,y,z) (((x)>=(y))&&((y)<=(z)))?y:x
 
-#define R_FREE(x) { free(x); x = NULL; }
+#define R_FREE(x) { free((void *)x); x = NULL; }
 
 #if __WINDOWS__
 #define HAVE_REGEXP 0
@@ -354,6 +359,10 @@ static inline void *r_new_copy(int size, void *data) {
 #define PFMT64d "I64d"
 #define PFMT64u "I64u"
 #define PFMT64o "I64o"
+#define PFMTSZx "Ix"
+#define PFMTSZd "Id"
+#define PFMTSZu "Iu"
+#define PFMTSZo "Io"
 #define LDBLFMT "f"
 #define HHXFMT  "x"
 #else
@@ -361,6 +370,10 @@ static inline void *r_new_copy(int size, void *data) {
 #define PFMT64d "lld"
 #define PFMT64u "llu"
 #define PFMT64o "llo"
+#define PFMTSZx "zx"
+#define PFMTSZd "zd"
+#define PFMTSZu "zu"
+#define PFMTSZo "zo"
 #define LDBLFMT "Lf"
 #define HHXFMT  "hhx"
 #endif
